# vericred_client

VericredClient - the Ruby gem for the Vericred API

# Getting Started

## Signing Up

Visit our [Developer Portal](https://developers.vericred.com) to
create an account.

Once you have created an account, you can create one Application for your
Production environment and another for a Sandbox (select the appropriate Plan when you create the Application).

## SDKs

Our API follows standard REST conventions, so you can use any HTTP client
to integrate with us. You will likely find it easier to use one of our
[autogenerated SDKs](https://github.com/vericred/?query=vericred-),
which we make available for several common programming languages.

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/drugs?search_term=Lipitor"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v6`.  We support prior versions. Our latest
stable version is `v7` and we will indicate in the documentation for an
endpoint if it's required.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v6' "https://api.vericred.com/drugs?search_term=Lipitor"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their
`State`s we typically the associated data.  In this example, we would
provide an Array of `State`s and a `state_id` for each provider.  This is
done primarily to reduce the payload size since many of the `Provider`s
will share a `State`

### Simplified Example
```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` in the query string for a `GET` or the body for a `POST`.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,states.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/1234567898?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1234567898,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```

# Plan and Rate Data

Vericred's Plan and Rate Data let you search and quote Major Medical and Ancillary Insurance Plans in a given area for a particular family in the Individual Market or a group of families in the Small Group Market.  Vericred provides the relevant data via this API and via our Bulk Format (documented [below](#Bulk Plan and Rate Data))

## Plans

A Plan defines a set of Benefits available to its purchaser.  For example, a Major Medical Plan would specify cost-share Benefits for services like a Primary Care Provider visit, a Specialist visit or an Emergency Room visit.  A Dental Plan might specify Benefits for Periodontics and Fluroride Treatments.  The Benefits for each Product type ([Major Medical](#header-major-medical), [Dental](#header-dental), and [Vision](#header-vision)) are documented below.

### Benefits Format

Benefits for Plans can be quite complex.  With the goals of capturing and standardizing the complexity while retaining a human-readable format, we have developed a [Bakus-Naur Form](https://en.wikipedia.org/wiki/Backus%E2%80%93Naur_form)(BNF) context-free grammar, with which we present Benefits.

Benefit cost-share strings are formatted to capture:
 * Network tiers
 * Compound or conditional cost-share
 * Limits on the cost-share
 * Benefit-specific maximum out-of-pocket costs

**Example #1**
As an example, we would represent [this Summary of Benefits &amp; Coverage](https://s3.amazonaws.com/vericred-data/SBC/2017/33602TX0780032.pdf) as:

* **Hospital stay facility fees**:
  - Network Provider: `$400 copay/admit plus 20% coinsurance`
  - Out-of-Network Provider: `$1,500 copay/admit plus 50% coinsurance`
  - Vericred's format for this benefit: `In-Network: $400 before deductible then 20% after deductible / Out-of-Network: $1,500 before deductible then 50% after deductible`

* **Rehabilitation services:**
  - Network Provider: `20% coinsurance`
  - Out-of-Network Provider: `50% coinsurance`
  - Limitations & Exceptions: `35 visit maximum per benefit period combined with Chiropractic care.`
  - Vericred's format for this benefit: `In-Network: 20% after deductible / Out-of-Network: 50% after deductible | limit: 35 visit(s) per Benefit Period`

**Example #2**
In [this other Summary of Benefits &amp; Coverage](https://s3.amazonaws.com/vericred-data/SBC/2017/40733CA0110568.pdf), the **specialty_drugs** cost-share has a maximum out-of-pocket for in-network pharmacies.
* **Specialty drugs:**
  - Network Provider: `40% coinsurance up to a $500 maximum for up to a 30 day supply`
  - Out-of-Network Provider `Not covered`
  - Vericred's format for this benefit: `In-Network: 40% after deductible, up to $500 per script / Out-of-Network: 100%`

**BNF**

Here's a description of the benefits summary string, represented as a context-free grammar:

```
root                      ::= coverage

coverage                  ::= (simple_coverage | tiered_coverage) (space pipe space coverage_modifier)?
tiered_coverage           ::= tier (space slash space tier)*
tier                      ::= tier_name colon space (tier_coverage | not_applicable)
tier_coverage             ::= simple_coverage (space (then | or | and) space simple_coverage)* tier_limitation?
simple_coverage           ::= (pre_coverage_limitation space)? coverage_amount (space post_coverage_limitation)? (comma? space coverage_condition)?
coverage_modifier         ::= limit_condition colon space (((simple_coverage | simple_limitation) (semicolon space see_carrier_documentation)?) | see_carrier_documentation | waived_if_admitted | shared_across_tiers)
waived_if_admitted        ::= ("copay" space)? "waived if admitted"
simple_limitation         ::= pre_coverage_limitation space "copay applies"
tier_name                 ::= "In-Network-Tier-2" | "Out-of-Network" | "In-Network"
limit_condition           ::= "limit" | "condition"
tier_limitation           ::= comma space "up to" space (currency | (integer space time_unit plural?)) (space post_coverage_limitation)?
coverage_amount           ::= currency | unlimited | included | unknown | percentage | (digits space (treatment_unit | time_unit) plural?)
pre_coverage_limitation   ::= first space digits space time_unit plural?
post_coverage_limitation  ::= (((then space currency) | "per condition") space)? "per" space (treatment_unit | (integer space time_unit) | time_unit) plural?
coverage_condition        ::= ("before deductible" | "after deductible" | "penalty" | allowance | "in-state" | "out-of-state") (space allowance)?
allowance                 ::= upto_allowance | after_allowance
upto_allowance            ::= "up to" space (currency space)? "allowance"
after_allowance           ::= "after" space (currency space)? "allowance"
see_carrier_documentation ::= "see carrier documentation for more information"
shared_across_tiers       ::= "shared across all tiers"
unknown                   ::= "unknown"
unlimited                 ::= /[uU]nlimited/
included                  ::= /[iI]ncluded in [mM]edical/
time_unit                 ::= /[hH]our/ | (((/[cC]alendar/ | /[cC]ontract/) space)? /[yY]ear/) | /[mM]onth/ | /[dD]ay/ | /[wW]eek/ | /[vV]isit/ | /[lL]ifetime/ | ((((/[bB]enefit/ plural?) | /[eE]ligibility/) space)? /[pP]eriod/)
treatment_unit            ::= /[pP]erson/ | /[gG]roup/ | /[cC]ondition/ | /[sS]cript/ | /[vV]isit/ | /[eE]xam/ | /[iI]tem/ | /[sS]tay/ | /[tT]reatment/ | /[aA]dmission/ | /[eE]pisode/
comma                     ::= ","
colon                     ::= ":"
semicolon                 ::= ";"
pipe                      ::= "|"
slash                     ::= "/"
plural                    ::= "(s)" | "s"
then                      ::= "then" | ("," space) | space
or                        ::= "or"
and                       ::= "and"
not_applicable            ::= "Not Applicable" | "N/A" | "NA"
first                     ::= "first"
currency                  ::= "$" number
percentage                ::= number "%"
number                    ::= float | integer
float                     ::= digits "." digits
integer                   ::= /[0-9]/+ (comma_int | under_int)*
comma_int                 ::= ("," /[0-9]/*3) !"_"
under_int                 ::= ("_" /[0-9]/*3) !","
digits                    ::= /[0-9]/+ ("_" /[0-9]/+)*
space                     ::= /[ \t]/+
```


### Major Medical

Vericred's data covers all Major Medical Plans available in the Individual and Small Groups (2-50 or 2-100) Markets in the US.  These Plans are governed by CMS and are ACA-compliant.  We do not include certain Plans that fall outside of the ACA, for example, Faith-Based Plans or Short-Term Medical Plans

We support the following Benefits Fields for Major Medical Plans.  These represent the vast majority of fields available on a [Summary of Benefits and Coverage](https://www.healthcare.gov/health-care-law-protections/summary-of-benefits-and-coverage/)

The following are the appropriate Benefit Fields for Major Medical:

- ambulance
- child\_eye\_exam
- child\_eyewear
- chiropractic\_services
- diagnostic\_test
- durable\_medical\_equipment
- emergency\_room
- family\_drug\_deductible
- family\_drug\_moop
- family\_medical\_deductible
- family\_medical\_moop
- generic\_drugs
- habilitation\_services
- home\_health\_care
- hospice\_service
- imaging\_center
- imaging\_physician
- individual\_drug\_deductible
- individual\_drug\_moop
- individual\_medical\_deductible
- individual\_medical\_moop
- inpatient\_birth
- inpatient\_birth\_physician
- inpatient\_facility
- inpatient\_mental\_health
- inpatient\_physician
- inpatient\_substance
- lab\_test
- non\_preferred\_brand\_drugs
- nonpreferred\_generic\_drug\_share
- nonpreferred\_specialty\_drug\_share
- outpatient\_ambulatory\_care\_center
- outpatient\_facility
- outpatient\_mental\_health
- outpatient\_physician
- outpatient\_substance
- plan\_coinsurance
- postnatal\_care
- preferred\_brand\_drugs
- prenatal\_care
- preventative\_care
- primary\_care\_physician
- rehabilitation\_services
- skilled\_nursing
- specialist
- specialty\_drugs
- telemedicine
- urgent\_care

### Dental

Dental benefits are less standardized than [Major Medical](#header-major-medical).  Because of this, we have captured benefits for the most commonly specified services and procedures.  If a Plan only specifies cost-share for "Major", "Minor", "Elective", etc, we determine the category for each of the benefits that we support and display the appropriate value for its category.

To view the technical documentation, [click here](#dental-plans).

The following are the supported Benefit Fields for Dental:

- bridges
- crowns
- denture\_relines\_rebases
- denture\_repair\_and\_adjustments
- dentures
- emergency\_treatment
- endodontics
- family\_annual\_max
- family\_deductible
- fluoride\_treatment
- implants
- individual\_annual\_max
- individual\_deductible
- inlays
- onlays
- oral\_exam
- oral\_surgery
- orthodontics\_adult
- orthodontics\_child
- periodontal\_maintenance
- periodontics
- prophylaxis\_cleaning
- radiograph\_bitewings
- radiograph\_other
- restoration\_fillings
- sealant
- simple\_extraction
- space\_maintainers

### Vision

Vision benefits are similar in structure to [Dental](#header-dental).  Again, when benefits are broken out by category, we determine the appropriate category for each service or procedure and display the approprate value for its category.

To view the technical documentation, [click here](#vision-plans).

The following are the supported Benefit Fields for Vision:

- eye\_exam
- retinal\_imaging
- frame
- eyeglass\_lenses\_single\_vision
- eyeglass\_lenses\_bifocal
- eyeglass\_lenses\_trifocal
- eyeglass\_lenses\_lenticular
- uv\_coating
- tint
- standard\_antireflective\_coating
- premium\_antireflective\_coating
- standard\_polycarbonate\_lenses\_child
- standard\_polycarbonate\_lenses\_adult
- standard\_progressive\_lenses
- premium\_progressive\_lenses
- standard\_scratch\_resistance
- polarized\_lenses
- photochromatic\_lenses
- standard\_contact\_lens\_fit\_and\_follow\_up
- premium\_contact\_lens\_fit\_and\_follow\_up
- contact\_lenses\_conventional
- contact\_lenses\_disposable
- contact\_lenses\_medically\_necessary
- laser\_vision\_correction
- additional\_pairs\_of\_eyeglasses

### Medicare Advantage

Medicare Advantage endpoints support MA (Medicare Advantage plans without prescription drug benefits), MAPD (Medicare Advantage plans with prescription drug benefits), and PDP (prescription drug benefits only) plans.

Medical and hospital benefits - we support over 4000 individual plans through our API nationwide. At this time, we do not support EGHP (employer group health plans).

Prescription drug benefits - drug benefits are categorized into initial coverage phase, coverage gap phase, and catastrophic phase. Each phase is broken down by drug tiers, pharmacy tiers, and length of supply.

[Click here](#header-medicare-advantage-quotes) to learn more about quoting Medicare Advantage plans.

## Rates

Rates are returned from the API as a part of [Quoting](#header-quoting).  We calculate Rates in one of two ways.

### Sheet Rates
When a Carrier supplies us with Sheet Rates, we display *exactly* the value provided to us.  For example, in the Major Medical market, most Carriers provide a single rate for each combination of Applicant age and tobacco status in a given [Rating Area](#header-rating-areas).  For example, in Austin, TX, a 21-year-old non-tobacco-user may be $312.41 per month while a 22-year-old tobacco-user may be $401.75 per month.  Certain Vision and Dental Carriers supply Sheet Rates as well, though it is less common.

### Rate Factors
Certain [Major Medical](#header-major-medical) Carriers and most [Vision](#header-vision) and [Dental](#header-dental) Carriers supply Rate Factors.  The attributes on which the factors are based are the same as [Sheet Rates](#header-sheet-rates) for the [Major Medical](#header-major-medical) market (due to restrictions on what factors may be used in ACA Plans, which limit the possible factors to age and tobacco status).

In [Dental](#header-dental) and [Vision](#header-vision), the types of [Rate Factors](#header-rate-factors) are more varied.  For example, SIC Code and Group size in the Group market and Gender in the Individual Market are commonly used [Rate Factors](#header-rate-factors)

Other common [Rate Factors](#header-rate-factors) for [Dental](#header-dental) and [Vision](#header-vision) products are Geographic and "Trend" (enrollment date) Factors.  In [Major Medical](#header-major-medical), these types of variance are handled by CMS-defined [Rating Areas](#header-rating-areas).

In order to calculate a Rate using [Rate Factors](#header-rate-factors), the following methodology is applied:

```
B = Base Rate
f = Rate Factor Function 1
f' = Rate Factor Function 2

B * f(x) * f'(y) [* f''(z)] ... = n
```

## Rating Areas
For [Major Medical](#header-major-medical) products, [CMS](https://www.cms.gov/) defines [Rating Areas](https://www.cms.gov/cciio/programs-and-initiatives/health-insurance-market-reforms/state-gra.html).  Under the ACA, *all* [Rate Factors](#header-rate-factors) in a Rating Area must be identical for a given time period.  E.g. in Arizona, the rate for a 21-year-old non-tobacco user must be identical in all counties contained in Rating Area 1 (Mohave, Coconino, Apache, and Navajo), but *may* be different than the rate for a 21-year-old non-tobacco user in all counties Rating Area 2 (Yavapai county only) for a given year in the Individual Market and a given quartern in the Small Group market.

[Rating Areas](#header-rating-areas) are defined either by County, Zip Code or both, depending on the State.  Because of this variance, all API endpoints that require a [Location](#header-specifying-the-location) require both `zip_code` and `fips_code` (a county code).  [Bulk Data](#bulkplanandratedata) for [Rating Areas](#bulkratingareas) and [Service Areas](#bulkserviceareas) also specifies locations using both `zip_code` and `fips_code`.

*Rating Areas do not apply to products other than [Major Medical](#header-major-medical)*

## Service Areas
CMS mandates that [Major Medical](#header-major-medical) Rates be defined by [Rating Areas](#header-rating-areas), which themselves define a geography in which Plans are offered.  Carriers often choose *not* to offer a Plan in and entire [Rating Area](#header-rating-areas) due to network coverage or other factors.  Instead, the Carrier would define a [Service Area](#header-service-areas) that specifies where a given Plan is offered.

Each Plan is available in a single [Service Area](#header-service-areas) and each [Service Area](#header-service-areas) is defined by either County, Zip Code, or both, depending on the Carrier.  Because of this variance, all API endpoints that require a [Location](#header-specifying-the-location) require both `zip_code` and `fips_code` (a county code). [Bulk Data](#bulkplanandratedata) for [Rating Areas](#bulkratingareas) and [Service Areas](#bulkserviceareas) also specifies locations using both `zip_code` and `fips_code`.

In [Dental](#header-dental) and [Vision](#header-vision) plans, we use a [Service Area](#header-service-areas) to define availability as well, although it typically mirrors a Geographic [Rate Factor](#header-rate-factors).

# Quoting

One of the primary use-cases for the Vericred API is to run Quotes to determine the Rate for a given family (in the Individual Market) or group (in the Small Group Market).  We support quoting across [Major Medical](#header-major-medical), [Vision](#header-vision), and [Dental](#header-dental).  In both cases, the process of generating a Quote is broken out into several steps:

1. Find all available [Plans](#header-plans) in the relevent [Service Areas](#header-service-areas) for the family or group.
1. Using [Business Rules](#header-business-rules) for each [Plan](#header-plans), determine if the family or group is eligible for that [Plan](#header-plans).
1. Using [Business Rules](#header-business-rules) for each [Plan](#header-plans), determine which members of the family or which members of each family in the group should be considered for Rating.
1. Using the [Sheet Rates](#header-sheet-rates) or [Rate Factors](#header-rate-factors) for each [Plan](#header-plans), determine the Rate the family, or for each family in the group.
1. If running a [Composite](#compositerates) quote, determine the portion of the total Rate that each family will pay.

## Individual Quotes
An Individual Quote is one for Plans that are available to a particular family, outside the context of their Employer.  In the [Major Medical](#header-major-medical) market, many of these Plans are available on [Healthcare.gov](https://www.healthcare.gov) or the State-Based Exchange for non-Healthcare.gov states.  The API supports both on-market and off-market Plans.

For details on Major Medical Quoting API calls see [below](#medicalplans-medicalplans-post)

### Specifying the Location
In order to determine which plans are [available](#header-service-areas) and the [rate](#header-rating-areas) for each Plan, you must specify a location.  When creating a [Quote](#header-quoting) for the Individual Market, that information is contained in the `POST` body of the request:
```
POST /plans/medical/search
{
  ...
  "zip_code": "11201",
  "fips_code": "36047"
  ...
}

```

### Specifying Applicants
Applicants are the members of the family being quoted and are specified in the `POST` body of the request.
```
POST /plans/medical/search
{
  ...
  "applicants": [
    {
      "age": 34,
      "smoker": true,
      "child": false
    },
    {
      "age": 32,
      "smoker": false,
      "child": false
    },
    {
      "age": 4,
      "smoker": false,
      "child": true
    }
  ]
  ...
}
```

### Specifying Enrollment Date
The `enrollment_date` determines which [Plans](#header-plans) and [Rates](#header-rates) are returned.  Specifying an `enrollment_date` in the past allows you to calculate historical data as far back as 2014.

### Plan Benefits
Plan Benefits are returned in the response for [Individual Quotes](#individualquotes)
```
POST /plans/medical/search
{
  ...
}

Response:
{
  "plans": [
    {
      ...
      "individual_medical_deductible": "$5,000",
      "family_medical_deductible": "$10,000"
      ...
    }

  ]
}

```

### Premiums
The value for the family being quoted is returned in the `premium` field.  If no [Applicants](#specifyingapplicants) are provided, the `premium` field will be `0`

### Major Medical Quotes
In order to [Quote](#header-quoting) [Major Medical](#header-major-medical) Plans, send a `POST` to `/plans/medical/search`.  In addition, the `age`, `smoker` and `child` attributes of each Applicant must be present.

#### Subsidies
On-market ([Healthcare.gov](https://www.healthcare.gov) and State-Based Exchange) [Major Medical](#header-major-medical) Plans are eligible for government subsidies.  The subsidy calculation is based on the percentage of the family's income that the IRS has designated as "affordable" for that family and the Second Lowest-Cost Silver Plan available to that family.

In order to calculate subsidies for a family the following parameters must be supplied:
```
POST /plans/medical/search
{
  ...
  "household_size": 4,
  "household_income": 40000
  ...
}
```

The amount that the family will pay after subsidy is returned in the `premium_subsidized` field for each plan.

##### Subsidy Calculation
Here is how subsidies are calculated.  This is fully handled by the Vericred API, but the steps are enumerated below for clarity.

1. Determine the percentage of the [Federal Poverty Level](https://aspe.hhs.gov/poverty-guidelines) for the family based on the household size and income.
1. Reference the [CMS table](https://www.irs.gov/pub/irs-drop/rp-17-36.pdf) to determine the appropriate percentage of income for the family to spend on healthcare.
1. Multiply that value by the family's income.  This is the total amount that the family can spend on healthcare for the year, after the subsidy.
1. Find the cost of the Second Least-Expensive Silver Plan available to the family, accounting for the percentage of premium that goes to [Essential Health Benefits](https://www.healthcare.gov/glossary/essential-health-benefits/)
1. Calculate the difference in price between the amount the family should spend on healthcare and the Second Least-Expensive Silver Plan's premium.  This is the subsidy.
1. Apply the subsidy to all on-market Plans available to the family.  The subsidized premium can never be below $0 (for example, a low-cost Bronze Plan may be less expensive than the subsidy)

#### Cost Sharing Reduction Plans
[Cost Sharing Reduction (CSR)](https://www.healthcare.gov/glossary/cost-sharing-reduction/) Plans are available to lower income families and offer enhanced benefits for certain Silver Plans at the same cost as the non-CSR Plans available to higher-income families.

If a family is eligible for CSR Plans, the Vericred API will return the relevant Plan in place of the non-CSR version.

In order to include CSR Plans where applicable, the following parameters must be supplied:
```
POST /plans/medical/search
{
  ...
  "household_size": 4,
  "household_income": 40000
  ...
}
```

#### The Children's Health Insurance Program (CHIP)
[The Children's Health Insurance Program (CHIP)](https://www.healthcare.gov/medicaid-chip/childrens-health-insurance-program/) provides low-cost health coverage to children in families that earn too much money to qualify for Medicaid.

If a family is eligible for CHIP, the Vericred API will include the subsidy in the returned premiums. In order to include CHIP subsidies in premium calculations, the following parameters must be supplied:
```
POST /plans/medical/search
{
  ...
  "applicants": [
    {
      "age": 34,
      "smoker": true,
      "child": false
    },
    {
      "age": 32,
      "smoker": false,
      "child": false
    },
    {
      "age": 4,
      "smoker": false,
      "child": true
    },
    {
      "age": 4,
      "smoker": false,
      "child": true
    }
  ],
  "household_size": 4,
  "household_income": 40000
  ...
}
```

CHIP eligibility is displayed within the meta-tag in the response as `eligible_for_chip_medicaid`:
```
{
  "meta": {
      "total": 150,
      "eligible_for_chip_medicaid": true,
      "premium_tax_credit": 500.20
    },
  "coverages": [],
  "plans": [...]
}
```

If you do not want CHIP subsidies to be included in the premiums, simply do not include the `household_income` parameter in the request.

### Dental Quotes
Quoting [Dental](#header-dental) Plans for a family requires slightly different parameters for [Applicants](#specifyingapplicants), due to the method with which Plans are [rated](#header-rate-factors).  The folloiwng example contains the require parameters:
```
POST /plans/dental/search
{
  ...
  "applicants": [
    {
      "age": 34,
      "gender": "M",
      "child": false
    },
    {
      "age": 32,
      "gender": "F",
      "child": false
    },
    {
      "age": 4,
      "gender": "M",
      "child": true
    }
  ]
  ...
}
```

Note that in contrast to [Major Medical Quotes](#majormedicalquotes), [Dental Quotes](#dentalquotes) require `gender`, but *do not* require `smoker`.

Also note that [Subsidies](#subsidies) and [Cost Sharing Reduction](#costsharingreductionplans) are *not* relevant for [Dental Quotes](#dentalquotes).

### Vision Quotes

Quoting [Vision](#header-vision) Plans for a family requires slightly different parameters for [Applicants](#specifyingapplicants), due to the method with which Plans are [rated](#header-rate-factors).  The folloiwng example contains the require parameters:
```
POST /plans/vision/search
{
  ...
  "applicants": [
    {
      "age": 34,
      "gender": "M",
      "child": false
    },
    {
      "age": 32,
      "gender": "F",
      "child": false
    },
    {
      "age": 4,
      "gender": "M",
      "child": true
    }
  ]
  ...
}
```

Note that in contrast to [Major Medical Quotes](#majormedicalquotes), [Vision Quotes](#visionquotes) require `gender`, but *do not* require `smoker`.

Also note that [Subsidies](#subsidies) and [Cost Sharing Reduction](#costsharingreductionplans) are *not* relevant for [Vision Quotes](#visionquotes).

### Medicare Advantage quotes

Given an enrollment date and location, you can search all plans available at this location using [/plans/medadv/search](#medicare-advantage-plans-medicare-advantage-plans-post); you can also search a specific plan using its plan ID with [/plans/medadv/{plan_id}](#medicare-advantage-plans-medicare-advantage-plans-get) if the plan ID is already known. The following example contains the required parameters:
```
{
"zip_code": "02880",
"fips_code": "44009",
"enrollment_date": "2019-01-01"
}
```
To view the technical documentation, [click here](#medicare-advantage-plans).


## Quotes for Groups
A Group Quote finds [Plans](#header-plans) and [Rates](#header-rates) for a group of employees for a small business.  Different [Plans](#header-plans) are available to small groups than are available in [Individual Quoting](#individualquotes).  In addition, [Business Rules](#header-business-rules) that apply across multiple families or based upon employer attributes such as [SIC](https://en.wikipedia.org/wiki/Standard_Industrial_Classification) code factor into rates and availability.

In addition, due to performance requirements and for enhanced auditing, [Group Quotes](#groupquotes) are persisted across requests.  This means that a given [Quote](#groupquotes) can be retrieved after it has been created.

### Identifiers
In order to make it easier to cross-reference local copies of data with [Quotes](#header-creating-a-quote) and other data in the Vericred API, most entities allow for the specification of an `external_id` field.  You can use this to store a primary or natural key from your system in order to easily match records returned from the API with records in your system.

### Specifying the Group
Creating a group is the first step in [Group Quoting](#groupquoting).  The API requires that certain information such as `sic_code`, and `chamber_association` be provided and returns a the attributes and `id` for the newly created `Group`

Full documentation is available [below](#groupscreate)

### Specifying the Locations
When creating a `Group`, you must also specify one or more `Location`s. Of those `Location`s specified, one must be `primary`.  That `Location` is used to calculate Plan eligibility using the relevant [Service Areas](#header-service-areas).  Some Carriers use secondary `Location`s to determine eligibility as well, which is why those must be specified as well.

```
POST /groups
{
  "group": {
    ...
  },
  "locations": [
    {
      ...
      "zip_code": "11201",
      "fips_code": "36047",
      "primary": true
      ...
    }
  ]
}
```

### Specifying the Census
A Census is the collection of `Member`s contained in the `Group`.  The attributes of each `Member` and his or her `Dependent`s determine the [Rate](#header-rates) for the `Group` as a whole.  Certain attributes of the `Member` are important for calculating [Rates](#header-rates) and applying [Business Rules](#header-business-rules).  For example, the `Member`'s home address and in which office he or she works are relevant for certain [Business Rules](#header-business-rules).

#### Dependent Relationships
The `Dependent`s for a given `Member` also factor into the [Rates](#header-rates) and application of [Business Rules](#header-business-rules).  For example, certain [Plans](#header-plans) cover only `Dependent`s of particular types and/or only `Dependent`s of a particular type who live in the same household as the primary `Member`

Valid Dependent Relationships:
- `adopted_child`
- `child`
- `court_appointed_guardian`
- `dependent_of_dependent`
- `ex_spouse`
- `foster_child`
- `grand_child`
- `guardian`
- `life_partner`
- `other`
- `sibling`
- `sponsored_dependent`
- `spouse`
- `step_child`
- `ward`

```
POST

/groups/{id}/members
{
  "members": [
    ...
    {
      "cobra": false,
      "date_of_birth": "1980-01-01",
      "fips_code": "36047"
      "gender": "M",
      "last_used_tobacco": "2017-01-01",
      "location_id": :location_id
      "retiree": false,
      "zip_code": "11201",
      "dependents": [
        ...
        {
          "relationship": "child",
          "same_household": true
        }
        ...
      ]
    }
    ...
  ]
}

```

### Creating a Quote
Once the [Census](#header-specifying-the-census) has been created, we can generate a `Quote` for the `Group`.

#### Major Medical Quotes
To generate a [Major Medical](#header-major-medical) Quote, specify the `product_line` of `Quote` as `medical`

```
POST /groups/{id}/quotes
{
  ...
  "product_line": "medical"
  ...
}
```

#### Dental Quotes
To generate a [Dental](#header-dental) Quote, specify the `product_line` of `Quote` as `dental`

```
POST /groups/{id}/quotes
{
  ...
  "product_line": "dental"
  ...
}
```

#### Vision Quotes
To generate a [Vision](#header-vision) Quote, specify the `product_line` of `Quote` as `vision`

```
POST /groups/{id}/quotes
{
  ...
  "product_line": "vision"
  ...
}
```

### Retrieving Aggregate Rates
Once you have created a [Quote](#header-creating-a-quote), you can retrieve its aggregate [Rates](#header-rates).  [Rates](#header-rates) are broken down by `Member` and `Dependent`, so that you can show the final cost in different scenarios where an employer might cover a different percentage of `Member` and `Dependent` costs.

```
GET /quotes/{id}/rates

Response
{
  "rates": [
    ...
    {
      "id": "123abc",
      "plan_id": "12345NY6789012",
      "total_premium": "2800.00",
      "member_premium": "1000.00",
      "dependent_premium": "1800.00",
      "premiums": {
        "age_banded": {
          "total_member": "1000.00",
          "total_dependent": "1800.00",
          "total": "2800.00"
        },
        "2_tier_composite": {
        "employee_only": "200.00",
        "employee_plus_family": "400.00",
        "total": "2800.00"
        },
        "3_tier_composite": {
          "employee_only": "200.00",
          "employee_plus_one": "250.00",
          "employee_plus_family": "330.00",
          "total": "2800.00"
        },
        "4_tier_composite": {
          "employee_only": "200.00",
          "employee_plus_child": "220.00",
          "employee_plus_spouse": "250.00",
          "employee_plus_family": "330.00",
          "total": "2800.00"
        }
      }
    }
    ...
  ]
}
```


#### Loading Plan Data
Aggregate [Rates](#header-rates) responses *do not* include [Plan](#header-plans) details in order to keep the payload small.  [Plan](#header-plans) data can be retrieved in one of two ways:

Loading the [Plan](#header-plans) from the API:
```
GET /plans/{id}

Response:
{
  "plans": [
    ...
    {
      ...
      "individual_medical_deductible": "$5,000",
      "family_medical_deductible": "$10,000",
      ...
    }
    ...

  ]
}
```
Pulling in [Bulk Plan Data](#bulkplans) and matching up [Plans](#header-plans) by their `id`.

### Retrieving Member-Level Rates
In order to retrieve the exact [Rate](#header-rates) for each `Member` and their `Dependents` for given [Plan](#header-plans), you can load Member-Level `Rates`.

```
GET /rates/{id}/member_rates

Response
{
  "member_rates": [
  ...
  {
    "id": "123abc",
    "member_id": "234def",
    "member_external_id": "externally-supplied-id",
    "member_premium": 500.0,
    "dependent_premium": 600.0,
    "total_premium": 1100.0
  }
  ...
  ]
}

```

Note that *all* `MemberRate`s are for one particular [Plan](#header-plans) - the one referenced by the parent [Rate](#header-rates).

### Business Rules
Vericred works with our Carrier partners to acquire and apply Business Rules that can affect either [Plan](#header-plans) availability or the way in which `Member`s and `Dependent`s are rated.  For example, one Carrier's Business Rules might specify that `Member`s and `Dependent`s who have used tobacco in the past 4 months are considered "tobacco-users", while another's may specify that period to be 1 year.

These rules are applied transparently during the [Quoting](#header-quoting) process and *do not* require any additional action or input on your part.

For a full accounting of Business Rules and a list of Carriers whose Business Rules are applied, please contact support@vericred.com

### Composite Rates
Composite Rates are commonly used in [Major Medical](#header-major-medical), [Dental](#header-dental), and [Vision](#header-vision) [Plans](#header-plans) to simplify operations by charging each family the weighted average of the `Group`'s total premium.  The most common methodology is as follows:

1. Calculate the [Rates](#header-rates) for the entire `Group` using [Sheet Rates](#header-sheet-rates) or [Rate Factors](#header-rate-factors) as appropriate
1. Categorize each Family within the Group.  The categorization differs depending on whether the Composite Rate is 2, 3, or 4-tier
1. Multiply the number of Families in each category by the constant for that category.  These constants are provided to Vericred by the Carrier.  This determines the total number of "Rating Units"
1. Divide the total premium calculated in Step 1 by the total number of Rating Units to get the price per Rating Unit
1. The [Rate](#header-rates) each Family pays is the constant for that Family's category multiplied by the price per Rating Unit.

You can request that a [Quote](#header-quoting) be calculated using Composite Rates when creating it:
```
POST /quotes
{
  ...
  "rating_method": "4_tier_composite"
  ...
}
```
If no Composite Rates methodology is available, the Vericred API will return standard age-banded Rates.

# Network and Provider Data

A `Provider` is an individual or organization in the medical profession.  For example, an individual doctor is a `Provider` as are certain clinics and hospitals.

`Provider`s are related to `Network`s.  A `Network` is a collection of `Provider`s that are under a particular contract with a given `Carrier`.  A given `Carrier` will often have multiple `Network`s.  For example, there may be a large national `Network` as well as several smaller regional `Network`s.

Each `Plan` has a `Network`.  A consumer who visits a `Provider` typically incurs fewer costs when visiting a `Provider` in the `Network` covered by his or her `Plan`.  The `premium` for a `Plan` is often proportional to the size of its `Network`

## Finding Providers
In order to determine if a particular `Plan` covers a given `Provider`, you must first identify the `Provider`.  To do so, use the [Provider Search API endpoint](#providers-providers-post) and specify some search criteria:

```
POST /providers/search
{
  "search_term": "foo",
  "zip_code": "11201"
}
```

The API will return an ordered list of `Provider`s who match the query along with their names, addresses, and other demographic data.  The `id` field returned refers to the `Provider`'s [NPI number](https://www.cms.gov/Regulations-and-Guidance/Administrative-Simplification/NationalProvIdentStand/).  This is the key that is used to identify the `Provider` across different API endpoints.

## Finding Networks

A `Network` is a collection of `Provider`s that are under a particular contract with a given `Carrier`.  A given `Carrier` will often have multiple `Network`s.  For example, there may be a large national `Network` as well as several smaller regional `Network`s.

The API supports searching for `Networks` by Carrier, market and state.  For more details view the [endpoint documentation](#networks-networks-get)

## Matching Providers to Networks
In order to determine if a `Provider` is covered by a user's `Plan`, you will need to map the `Provider` to a `Network`.  There are several methods to do this using the API

### Using Plan Search
You can specify one or more `npi` values in the [`plan` search](#majormedicalplans-majormedicalplans-post).  To do so, include a list of `providers` in the request
```
POST /plans/medical/search
{
  ...
  "providers": [
    { "npi": 1234567890 },
    { "npi": 2345678901 }
  ]
  ...
}

The response will then return a list of `in_network_ids` and `out_of_network_ids` for each `Plan`

```
{
  "plans": [
    ...
    {
      ...
      "id": "12345NY1234567",
      "in_network_ids": [1234567890],
      "out_of_network_ids": [1234567890]
      ...
    },
    {
      ...
      "id": "12345NY2345678",
      "in_network_ids": [1234567890, 1234567890],
      "out_of_network_ids": []
      ...
    }
    ...
  ]
}

Simply reference the `Provider` in question by its `id` for each `Plan` to see if that `Provider` is in-network for the `Plan`.

### Matching by Plan ID
Given a `Provider`'s `id`, you can retrieve all of his or her `hios_ids`

For more details see the [endpoint documentation](#providers-providers-get)

```
GET /providers/1234567890
{
  "provider": {
    ...
    "hios_ids": [
      ...
      "12345NY1234567"
      ...
    ]
    ...
  }
}
```

The returned `hios_ids` can be used to cross-reference a `Plan`

### Matching by Network
Once you have an ID returned from the [`Network` search endpoint](#networks-networks-get), you can cross-reference it with the `network_ids` returned from both the [`Provider` search](#providers-providers-post) and [`Provider` details](#providers-providers-get) endpoints.

This is useful for large group data or when you are not dealing with `Plan`s directly, but rather at the `Network` level.


This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 0.0.40
- Build package: class io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build vericred_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./vericred_client-0.0.40.gem
```
(for development, run `gem install --dev ./vericred_client-0.0.40.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'vericred_client', '~> 0.0.40'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'vericred_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'vericred_client'

# Setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::BulkPlansApi.new

body = VericredClient::PlansBulkSearchRequest.new # PlansBulkSearchRequest | 


begin
  #Plans in Bulk
  result = api_instance.find_bulk_plans(body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling BulkPlansApi->find_bulk_plans: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.vericred.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*VericredClient::BulkPlansApi* | [**find_bulk_plans**](docs/BulkPlansApi.md#find_bulk_plans) | **POST** /plans/bulk | Plans in Bulk
*VericredClient::CarrierGroupsApi* | [**delete_carrier_group**](docs/CarrierGroupsApi.md#delete_carrier_group) | **DELETE** /carrier_groups/{vericred_id} | Delete a CarrierGroup.
*VericredClient::CarrierGroupsApi* | [**put_carrier_group**](docs/CarrierGroupsApi.md#put_carrier_group) | **PUT** /carrier_groups/{vericred_id} | Create/update a CarrierGroup
*VericredClient::CarrierSubsidiaryDisclaimersApi* | [**delete_carrier_subsidiary_disclaimer**](docs/CarrierSubsidiaryDisclaimersApi.md#delete_carrier_subsidiary_disclaimer) | **DELETE** /carrier_subsidiary_disclaimers/{vericred_id} | Delete a Carrier Subsidiary Disclaimer
*VericredClient::CarrierSubsidiaryDisclaimersApi* | [**put_carrier_subsidiary_disclaimer**](docs/CarrierSubsidiaryDisclaimersApi.md#put_carrier_subsidiary_disclaimer) | **PUT** /carrier_subsidiary_disclaimers/{vericred_id} | Create/update a Carrier Subsidiary Disclaimer
*VericredClient::CarriersApi* | [**delete_carrier**](docs/CarriersApi.md#delete_carrier) | **DELETE** /carriers/{vericred_id} | Delete a Carrier.
*VericredClient::CarriersApi* | [**put_carrier**](docs/CarriersApi.md#put_carrier) | **PUT** /carriers/{vericred_id} | Create/update a Carrier
*VericredClient::DentalPlansApi* | [**delete_dental_plan**](docs/DentalPlansApi.md#delete_dental_plan) | **DELETE** /plans/dental/{vericred_id} | Delete a Dental Plan.
*VericredClient::DentalPlansApi* | [**find_dental_plans**](docs/DentalPlansApi.md#find_dental_plans) | **POST** /plans/dental/search | Search Plans
*VericredClient::DentalPlansApi* | [**put_dental_plan**](docs/DentalPlansApi.md#put_dental_plan) | **PUT** /plans/dental/{vericred_id} | Create/update a Dental Plan
*VericredClient::DentalPlansApi* | [**show_dental_plan**](docs/DentalPlansApi.md#show_dental_plan) | **GET** /plans/dental/{id} | Show Plan
*VericredClient::DentalPlansApi* | [**show_dental_plan_0**](docs/DentalPlansApi.md#show_dental_plan_0) | **GET** /plans/dental/{vericred_id} | Show Plan
*VericredClient::DrugsApi* | [**get_drug_coverages**](docs/DrugsApi.md#get_drug_coverages) | **GET** /drugs/{id}/coverages | Drug Coverage Search
*VericredClient::DrugsApi* | [**list_drugs**](docs/DrugsApi.md#list_drugs) | **GET** /drugs | Drug Search
*VericredClient::EmbargoesApi* | [**delete_embargo**](docs/EmbargoesApi.md#delete_embargo) | **DELETE** /embargoes/{vericred_id} | Delete an Embargo.
*VericredClient::EmbargoesApi* | [**put_embargo**](docs/EmbargoesApi.md#put_embargo) | **PUT** /embargoes/{vericred_id} | Create/update an Embargo
*VericredClient::FormulariesApi* | [**list_formularies**](docs/FormulariesApi.md#list_formularies) | **GET** /formularies | Formulary Search
*VericredClient::FormulariesApi* | [**show_formulary_drug_package_coverage**](docs/FormulariesApi.md#show_formulary_drug_package_coverage) | **GET** /formularies/{formulary_id}/drug_packages/{ndc_package_code} | Formulary Drug Package Search
*VericredClient::IssuersApi* | [**delete_issuer**](docs/IssuersApi.md#delete_issuer) | **DELETE** /issuers/{vericred_id} | Delete an Issuer.
*VericredClient::IssuersApi* | [**put_issuer**](docs/IssuersApi.md#put_issuer) | **PUT** /issuers/{vericred_id} | Create/update an Issuer
*VericredClient::MajorMedicalPlansApi* | [**find_major_medical_plans**](docs/MajorMedicalPlansApi.md#find_major_medical_plans) | **POST** /plans/medical/search | Search Plans
*VericredClient::MajorMedicalPlansApi* | [**show_medical_plan**](docs/MajorMedicalPlansApi.md#show_medical_plan) | **GET** /plans/medical/{id} | Show Plan
*VericredClient::MedicalPlansApi* | [**find_major_medical_plans**](docs/MedicalPlansApi.md#find_major_medical_plans) | **POST** /plans/medical/search | Search Plans
*VericredClient::MedicalPlansApi* | [**put_medical_plan**](docs/MedicalPlansApi.md#put_medical_plan) | **PUT** /plans/medical/{vericred_id} | Create/update a Medical Plan
*VericredClient::MedicalPlansApi* | [**show_medical_plan**](docs/MedicalPlansApi.md#show_medical_plan) | **GET** /plans/medical/{id} | Show Plan
*VericredClient::MedicareAdvantagePlansApi* | [**find_medicare_advantage_plans**](docs/MedicareAdvantagePlansApi.md#find_medicare_advantage_plans) | **POST** /plans/medadv/search | Search Plans
*VericredClient::MedicareAdvantagePlansApi* | [**put_medicare_advantage_plan**](docs/MedicareAdvantagePlansApi.md#put_medicare_advantage_plan) | **PUT** /plans/medadv/{vericred_id} | Create/update a Medicare Advantage Plan
*VericredClient::MedicareAdvantagePlansApi* | [**show_med_adv_plan**](docs/MedicareAdvantagePlansApi.md#show_med_adv_plan) | **GET** /plans/medadv/{id} | Show Plan
*VericredClient::NetworkSizesApi* | [**list_state_network_sizes**](docs/NetworkSizesApi.md#list_state_network_sizes) | **GET** /states/{state_id}/network_sizes | State Network Sizes
*VericredClient::NetworkSizesApi* | [**search_network_sizes**](docs/NetworkSizesApi.md#search_network_sizes) | **POST** /network_sizes/search | Network Sizes
*VericredClient::NetworksApi* | [**create_disruption_analysis**](docs/NetworksApi.md#create_disruption_analysis) | **POST** /networks/disruption_analysis | Disruption Analysis
*VericredClient::NetworksApi* | [**create_network_comparisons**](docs/NetworksApi.md#create_network_comparisons) | **POST** /networks/{id}/network_comparisons | Compare Multiple Networks
*VericredClient::NetworksApi* | [**list_networks**](docs/NetworksApi.md#list_networks) | **GET** /networks | Network Search
*VericredClient::NetworksApi* | [**show_network**](docs/NetworksApi.md#show_network) | **GET** /networks/{id} | Display a Network
*VericredClient::PlansApi* | [**delete_plan**](docs/PlansApi.md#delete_plan) | **DELETE** /plans/{hios}/{year} | Delete a plan
*VericredClient::ProvidersApi* | [**delete_provider**](docs/ProvidersApi.md#delete_provider) | **DELETE** /providers/{npi} | Delete an NPI from a provider.
*VericredClient::ProvidersApi* | [**get_provider_plans**](docs/ProvidersApi.md#get_provider_plans) | **GET** /providers/{npi}/plans | Provider Plans
*VericredClient::ProvidersApi* | [**get_providers**](docs/ProvidersApi.md#get_providers) | **POST** /providers/search | Find Providers
*VericredClient::ProvidersApi* | [**put_provider**](docs/ProvidersApi.md#put_provider) | **PUT** /providers/{npi} | Find a Provider
*VericredClient::QuotingApi* | [**create_group**](docs/QuotingApi.md#create_group) | **POST** /groups | Create a Group
*VericredClient::QuotingApi* | [**create_group_quote**](docs/QuotingApi.md#create_group_quote) | **POST** /groups/{id}/quotes | Create a Quote
*VericredClient::QuotingApi* | [**show_group**](docs/QuotingApi.md#show_group) | **GET** /groups/{id} | Display a Group
*VericredClient::QuotingApi* | [**show_group_rates**](docs/QuotingApi.md#show_group_rates) | **GET** /quotes/{id}/rates | Display Rates
*VericredClient::QuotingApi* | [**show_rate_member_rates**](docs/QuotingApi.md#show_rate_member_rates) | **GET** /rates/{id}/member_rates | Display Member Rates
*VericredClient::QuotingApi* | [**update_group_members**](docs/QuotingApi.md#update_group_members) | **PUT** /groups/{id}/members | Create or Update Members
*VericredClient::RatesApi* | [**delete_rate**](docs/RatesApi.md#delete_rate) | **DELETE** /rates/{vericred_id} | Delete a Rate.
*VericredClient::RatesApi* | [**put_rate**](docs/RatesApi.md#put_rate) | **PUT** /rates/{vericred_id} | Create/update a Rate
*VericredClient::ServiceAreasApi* | [**put_service_area**](docs/ServiceAreasApi.md#put_service_area) | **PUT** /service_areas/{vericred_id} | Create/update a ServiceArea
*VericredClient::SpecialtiesApi* | [**get_specialties**](docs/SpecialtiesApi.md#get_specialties) | **GET** /specialties | Specialty Search
*VericredClient::VisionPlansApi* | [**delete_vision_plan**](docs/VisionPlansApi.md#delete_vision_plan) | **DELETE** /plans/vision/{vericred_id} | Delete a Vision Plan.
*VericredClient::VisionPlansApi* | [**find_vision_plans**](docs/VisionPlansApi.md#find_vision_plans) | **POST** /plans/vision/search | Search Plans
*VericredClient::VisionPlansApi* | [**put_vision_plan**](docs/VisionPlansApi.md#put_vision_plan) | **PUT** /plans/vision/{vericred_id} | Create/update a Vision Plan
*VericredClient::VisionPlansApi* | [**show_medical_plan**](docs/VisionPlansApi.md#show_medical_plan) | **GET** /plans/vision/{id} | Show Plan
*VericredClient::VisionPlansApi* | [**show_vision_plan**](docs/VisionPlansApi.md#show_vision_plan) | **GET** /plans/vision/{vericred_id} | Show Plan
*VericredClient::ZipCountiesApi* | [**get_zip_counties**](docs/ZipCountiesApi.md#get_zip_counties) | **GET** /zip_counties | Search for Zip Counties
*VericredClient::ZipCountiesApi* | [**show_zip_county**](docs/ZipCountiesApi.md#show_zip_county) | **GET** /zip_counties/{id} | Show an individual ZipCounty


## Documentation for Models

 - [VericredClient::ACAPlan](docs/ACAPlan.md)
 - [VericredClient::ACAPlan2018](docs/ACAPlan2018.md)
 - [VericredClient::ACAPlan2018Search](docs/ACAPlan2018Search.md)
 - [VericredClient::ACAPlan2018SearchResponse](docs/ACAPlan2018SearchResponse.md)
 - [VericredClient::ACAPlan2018SearchResult](docs/ACAPlan2018SearchResult.md)
 - [VericredClient::ACAPlan2018ShowResponse](docs/ACAPlan2018ShowResponse.md)
 - [VericredClient::ACAPlanPre2018](docs/ACAPlanPre2018.md)
 - [VericredClient::ACAPlanPre2018Bulk](docs/ACAPlanPre2018Bulk.md)
 - [VericredClient::ACAPlanPre2018Search](docs/ACAPlanPre2018Search.md)
 - [VericredClient::ACAPlanPre2018SearchResponse](docs/ACAPlanPre2018SearchResponse.md)
 - [VericredClient::ACAPlanPre2018SearchResult](docs/ACAPlanPre2018SearchResult.md)
 - [VericredClient::ACAPlanPre2018ShowResponse](docs/ACAPlanPre2018ShowResponse.md)
 - [VericredClient::Address](docs/Address.md)
 - [VericredClient::AdultChildTierComposite](docs/AdultChildTierComposite.md)
 - [VericredClient::AgeBanded](docs/AgeBanded.md)
 - [VericredClient::AncillaryPlanIdentifier](docs/AncillaryPlanIdentifier.md)
 - [VericredClient::Base](docs/Base.md)
 - [VericredClient::BasePlanSearchResponse](docs/BasePlanSearchResponse.md)
 - [VericredClient::BusinessRule](docs/BusinessRule.md)
 - [VericredClient::BusinessRuleSet](docs/BusinessRuleSet.md)
 - [VericredClient::Carrier](docs/Carrier.md)
 - [VericredClient::CarrierGroupRequest](docs/CarrierGroupRequest.md)
 - [VericredClient::CarrierRequest](docs/CarrierRequest.md)
 - [VericredClient::CarrierSubsidiary](docs/CarrierSubsidiary.md)
 - [VericredClient::CarrierSubsidiaryBulk](docs/CarrierSubsidiaryBulk.md)
 - [VericredClient::CarrierSubsidiaryDisclaimer](docs/CarrierSubsidiaryDisclaimer.md)
 - [VericredClient::Composite](docs/Composite.md)
 - [VericredClient::County](docs/County.md)
 - [VericredClient::CountyBulk](docs/CountyBulk.md)
 - [VericredClient::DentalPlan](docs/DentalPlan.md)
 - [VericredClient::DentalPlanBenefits](docs/DentalPlanBenefits.md)
 - [VericredClient::DentalPlanSearch](docs/DentalPlanSearch.md)
 - [VericredClient::DentalPlanSearchApplicant](docs/DentalPlanSearchApplicant.md)
 - [VericredClient::DentalPlanSearchRequest](docs/DentalPlanSearchRequest.md)
 - [VericredClient::DentalPlanSearchResponse](docs/DentalPlanSearchResponse.md)
 - [VericredClient::DentalPlanShowResponse](docs/DentalPlanShowResponse.md)
 - [VericredClient::DentalPlanUpdate](docs/DentalPlanUpdate.md)
 - [VericredClient::DentalPlanUpdateRequest](docs/DentalPlanUpdateRequest.md)
 - [VericredClient::DependentCreate](docs/DependentCreate.md)
 - [VericredClient::DependentCreateRequest](docs/DependentCreateRequest.md)
 - [VericredClient::DependentShow](docs/DependentShow.md)
 - [VericredClient::Drug](docs/Drug.md)
 - [VericredClient::DrugCoverage](docs/DrugCoverage.md)
 - [VericredClient::DrugCoverageBase](docs/DrugCoverageBase.md)
 - [VericredClient::DrugCoverageResponse](docs/DrugCoverageResponse.md)
 - [VericredClient::DrugDetails](docs/DrugDetails.md)
 - [VericredClient::DrugPackage](docs/DrugPackage.md)
 - [VericredClient::DrugSearchDrugPackage](docs/DrugSearchDrugPackage.md)
 - [VericredClient::DrugSearchRequest](docs/DrugSearchRequest.md)
 - [VericredClient::DrugSearchResponse](docs/DrugSearchResponse.md)
 - [VericredClient::EmbargoRequest](docs/EmbargoRequest.md)
 - [VericredClient::Formulary](docs/Formulary.md)
 - [VericredClient::FormularyDrugCoverage](docs/FormularyDrugCoverage.md)
 - [VericredClient::FormularyDrugPackageResponse](docs/FormularyDrugPackageResponse.md)
 - [VericredClient::FormularyResponse](docs/FormularyResponse.md)
 - [VericredClient::FourTierComposite](docs/FourTierComposite.md)
 - [VericredClient::GroupCreate](docs/GroupCreate.md)
 - [VericredClient::GroupCreateRequest](docs/GroupCreateRequest.md)
 - [VericredClient::GroupCreateResponse](docs/GroupCreateResponse.md)
 - [VericredClient::GroupShow](docs/GroupShow.md)
 - [VericredClient::GroupShowResponse](docs/GroupShowResponse.md)
 - [VericredClient::GroupUpdate](docs/GroupUpdate.md)
 - [VericredClient::GroupUpdateRequest](docs/GroupUpdateRequest.md)
 - [VericredClient::IssuerRequest](docs/IssuerRequest.md)
 - [VericredClient::Location](docs/Location.md)
 - [VericredClient::LocationCreate](docs/LocationCreate.md)
 - [VericredClient::LocationShow](docs/LocationShow.md)
 - [VericredClient::LocationUpdate](docs/LocationUpdate.md)
 - [VericredClient::MedicalPlanBenefits](docs/MedicalPlanBenefits.md)
 - [VericredClient::MedicalPlanSearchRequest](docs/MedicalPlanSearchRequest.md)
 - [VericredClient::MedicalPlanUpdate](docs/MedicalPlanUpdate.md)
 - [VericredClient::MedicalPlanUpdateRequest](docs/MedicalPlanUpdateRequest.md)
 - [VericredClient::MedicareAdvantagePlan](docs/MedicareAdvantagePlan.md)
 - [VericredClient::MedicareAdvantagePlanBenefits](docs/MedicareAdvantagePlanBenefits.md)
 - [VericredClient::MedicareAdvantagePlanSearch](docs/MedicareAdvantagePlanSearch.md)
 - [VericredClient::MedicareAdvantagePlanSearchRequest](docs/MedicareAdvantagePlanSearchRequest.md)
 - [VericredClient::MedicareAdvantagePlanSearchResponse](docs/MedicareAdvantagePlanSearchResponse.md)
 - [VericredClient::MedicareAdvantagePlanShowResponse](docs/MedicareAdvantagePlanShowResponse.md)
 - [VericredClient::MedicareAdvantagePlanUpdate](docs/MedicareAdvantagePlanUpdate.md)
 - [VericredClient::MedicareAdvantagePlanUpdateRequest](docs/MedicareAdvantagePlanUpdateRequest.md)
 - [VericredClient::MemberAdultChildTierComposite](docs/MemberAdultChildTierComposite.md)
 - [VericredClient::MemberAgeBanded](docs/MemberAgeBanded.md)
 - [VericredClient::MemberCreate](docs/MemberCreate.md)
 - [VericredClient::MemberPremiums](docs/MemberPremiums.md)
 - [VericredClient::MemberRateShow](docs/MemberRateShow.md)
 - [VericredClient::MemberRateShowRequest](docs/MemberRateShowRequest.md)
 - [VericredClient::MemberRatesShowResponse](docs/MemberRatesShowResponse.md)
 - [VericredClient::MemberShow](docs/MemberShow.md)
 - [VericredClient::MembersCreateRequest](docs/MembersCreateRequest.md)
 - [VericredClient::MembersCreateResponse](docs/MembersCreateResponse.md)
 - [VericredClient::MembersShowResponse](docs/MembersShowResponse.md)
 - [VericredClient::Meta](docs/Meta.md)
 - [VericredClient::MetaPlanSearchResponse](docs/MetaPlanSearchResponse.md)
 - [VericredClient::Network](docs/Network.md)
 - [VericredClient::NetworkComparison](docs/NetworkComparison.md)
 - [VericredClient::NetworkComparisonRequest](docs/NetworkComparisonRequest.md)
 - [VericredClient::NetworkComparisonResponse](docs/NetworkComparisonResponse.md)
 - [VericredClient::NetworkDetails](docs/NetworkDetails.md)
 - [VericredClient::NetworkDetailsResponse](docs/NetworkDetailsResponse.md)
 - [VericredClient::NetworkDisruptionAnalysis](docs/NetworkDisruptionAnalysis.md)
 - [VericredClient::NetworkDisruptionAnalysisRequest](docs/NetworkDisruptionAnalysisRequest.md)
 - [VericredClient::NetworkDisruptionAnalysisResponse](docs/NetworkDisruptionAnalysisResponse.md)
 - [VericredClient::NetworkSearch](docs/NetworkSearch.md)
 - [VericredClient::NetworkSearchResponse](docs/NetworkSearchResponse.md)
 - [VericredClient::NetworkSize](docs/NetworkSize.md)
 - [VericredClient::NotificationSubscription](docs/NotificationSubscription.md)
 - [VericredClient::NotificationSubscriptionResponse](docs/NotificationSubscriptionResponse.md)
 - [VericredClient::Plan](docs/Plan.md)
 - [VericredClient::PlanAncestor](docs/PlanAncestor.md)
 - [VericredClient::PlanCounty](docs/PlanCounty.md)
 - [VericredClient::PlanCountyBulk](docs/PlanCountyBulk.md)
 - [VericredClient::PlanDeleted](docs/PlanDeleted.md)
 - [VericredClient::PlanIdentifier](docs/PlanIdentifier.md)
 - [VericredClient::PlanMedicare](docs/PlanMedicare.md)
 - [VericredClient::PlanMedicareBulk](docs/PlanMedicareBulk.md)
 - [VericredClient::PlanNetwork](docs/PlanNetwork.md)
 - [VericredClient::PlanPricingMedicare](docs/PlanPricingMedicare.md)
 - [VericredClient::PlanShowResponse](docs/PlanShowResponse.md)
 - [VericredClient::PlansBulkACA2018Response](docs/PlansBulkACA2018Response.md)
 - [VericredClient::PlansBulkACAPre2018](docs/PlansBulkACAPre2018.md)
 - [VericredClient::PlansBulkBase](docs/PlansBulkBase.md)
 - [VericredClient::PlansBulkDental](docs/PlansBulkDental.md)
 - [VericredClient::PlansBulkSearchRequest](docs/PlansBulkSearchRequest.md)
 - [VericredClient::PlansBulkVision](docs/PlansBulkVision.md)
 - [VericredClient::Premiums](docs/Premiums.md)
 - [VericredClient::Provider](docs/Provider.md)
 - [VericredClient::ProviderDetails](docs/ProviderDetails.md)
 - [VericredClient::ProviderGeocode](docs/ProviderGeocode.md)
 - [VericredClient::ProviderNetworkEventNotification](docs/ProviderNetworkEventNotification.md)
 - [VericredClient::ProviderNetworkSpecialty](docs/ProviderNetworkSpecialty.md)
 - [VericredClient::ProviderNetworks](docs/ProviderNetworks.md)
 - [VericredClient::ProviderNetworksAddress](docs/ProviderNetworksAddress.md)
 - [VericredClient::ProviderPlanNetworkResponse](docs/ProviderPlanNetworkResponse.md)
 - [VericredClient::ProviderPlanResponse](docs/ProviderPlanResponse.md)
 - [VericredClient::ProviderPlans](docs/ProviderPlans.md)
 - [VericredClient::ProviderPlansRequest](docs/ProviderPlansRequest.md)
 - [VericredClient::ProviderShowResponse](docs/ProviderShowResponse.md)
 - [VericredClient::ProvidersGeocodeResponse](docs/ProvidersGeocodeResponse.md)
 - [VericredClient::ProvidersSearchResponse](docs/ProvidersSearchResponse.md)
 - [VericredClient::QuoteCreate](docs/QuoteCreate.md)
 - [VericredClient::QuoteCreateRequest](docs/QuoteCreateRequest.md)
 - [VericredClient::QuoteCreateResponse](docs/QuoteCreateResponse.md)
 - [VericredClient::QuoteShow](docs/QuoteShow.md)
 - [VericredClient::QuoteShowResponse](docs/QuoteShowResponse.md)
 - [VericredClient::RateRequest](docs/RateRequest.md)
 - [VericredClient::RateSearch](docs/RateSearch.md)
 - [VericredClient::RateShow](docs/RateShow.md)
 - [VericredClient::RateShowRequest](docs/RateShowRequest.md)
 - [VericredClient::RatesShowResponse](docs/RatesShowResponse.md)
 - [VericredClient::RatingArea](docs/RatingArea.md)
 - [VericredClient::RequestPlanFindApplicant](docs/RequestPlanFindApplicant.md)
 - [VericredClient::RequestPlanFindDrugPackage](docs/RequestPlanFindDrugPackage.md)
 - [VericredClient::RequestPlanFindProvider](docs/RequestPlanFindProvider.md)
 - [VericredClient::RequestProviderNotificationSubscription](docs/RequestProviderNotificationSubscription.md)
 - [VericredClient::RequestProvidersSearch](docs/RequestProvidersSearch.md)
 - [VericredClient::RequestRatesSearch](docs/RequestRatesSearch.md)
 - [VericredClient::ResponseRatesSearch](docs/ResponseRatesSearch.md)
 - [VericredClient::RxCuiIdentifier](docs/RxCuiIdentifier.md)
 - [VericredClient::RxCuiIdentifierSearchResponse](docs/RxCuiIdentifierSearchResponse.md)
 - [VericredClient::ServiceArea](docs/ServiceArea.md)
 - [VericredClient::ServiceAreaUpdate](docs/ServiceAreaUpdate.md)
 - [VericredClient::ServiceAreaZipCounty](docs/ServiceAreaZipCounty.md)
 - [VericredClient::ServiceAreaZipCountyUpdate](docs/ServiceAreaZipCountyUpdate.md)
 - [VericredClient::SpecialtySearchResponse](docs/SpecialtySearchResponse.md)
 - [VericredClient::SpecialtyShow](docs/SpecialtyShow.md)
 - [VericredClient::State](docs/State.md)
 - [VericredClient::StateNetworkSizeRequest](docs/StateNetworkSizeRequest.md)
 - [VericredClient::StateNetworkSizeResponse](docs/StateNetworkSizeResponse.md)
 - [VericredClient::SupplementalOptions](docs/SupplementalOptions.md)
 - [VericredClient::SupplementalOptionsUpdate](docs/SupplementalOptionsUpdate.md)
 - [VericredClient::ThreeTierComposite](docs/ThreeTierComposite.md)
 - [VericredClient::TwoTierComposite](docs/TwoTierComposite.md)
 - [VericredClient::V7NetworkComparisonResponse](docs/V7NetworkComparisonResponse.md)
 - [VericredClient::V7ResponseProvidersProviderDetails](docs/V7ResponseProvidersProviderDetails.md)
 - [VericredClient::VisionPlan](docs/VisionPlan.md)
 - [VericredClient::VisionPlanBenefits](docs/VisionPlanBenefits.md)
 - [VericredClient::VisionPlanSearch](docs/VisionPlanSearch.md)
 - [VericredClient::VisionPlanSearchApplicant](docs/VisionPlanSearchApplicant.md)
 - [VericredClient::VisionPlanSearchRequest](docs/VisionPlanSearchRequest.md)
 - [VericredClient::VisionPlanSearchResponse](docs/VisionPlanSearchResponse.md)
 - [VericredClient::VisionPlanShowResponse](docs/VisionPlanShowResponse.md)
 - [VericredClient::VisionPlanUpdate](docs/VisionPlanUpdate.md)
 - [VericredClient::VisionPlanUpdateRequest](docs/VisionPlanUpdateRequest.md)
 - [VericredClient::ZipCode](docs/ZipCode.md)
 - [VericredClient::ZipCountiesResponse](docs/ZipCountiesResponse.md)
 - [VericredClient::ZipCounty](docs/ZipCounty.md)
 - [VericredClient::ZipCountyBulk](docs/ZipCountyBulk.md)
 - [VericredClient::ZipCountyResponse](docs/ZipCountyResponse.md)


## Documentation for Authorization


### Vericred-Api-Key

- **Type**: API key
- **API key parameter name**: Vericred-Api-Key
- **Location**: HTTP header

