# VericredClient::DentalPlansApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_dental_plan**](DentalPlansApi.md#delete_dental_plan) | **DELETE** /plans/dental/{vericred_id} | Delete a Dental Plan.
[**find_dental_plans**](DentalPlansApi.md#find_dental_plans) | **POST** /plans/dental/search | Search Plans
[**put_dental_plan**](DentalPlansApi.md#put_dental_plan) | **PUT** /plans/dental/{vericred_id} | Create/update a Dental Plan
[**show_dental_plan**](DentalPlansApi.md#show_dental_plan) | **GET** /plans/dental/{id} | Show Plan
[**show_dental_plan_0**](DentalPlansApi.md#show_dental_plan_0) | **GET** /plans/dental/{vericred_id} | Show Plan


# **delete_dental_plan**
> delete_dental_plan(vericred_id)

Delete a Dental Plan.

Delete a Dental Plan from the database.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DentalPlansApi.new

vericred_id = "a234567b90" # String | The unique Vericred id


begin
  #Delete a Dental Plan.
  api_instance.delete_dental_plan(vericred_id)
rescue VericredClient::ApiError => e
  puts "Exception when calling DentalPlansApi->delete_dental_plan: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vericred_id** | **String**| The unique Vericred id | 

### Return type

nil (empty response body)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **find_dental_plans**
> DentalPlanSearchResponse find_dental_plans(body)

Search Plans

### Searching for Dental Plans  Determine the available Plans and their Premiums for a particular Family in a given Location. The overview on dental plans and plan benefits can be accessed [here](#header-dental).  For details on searching for Plans and their related data, see the [Quoting Dental Plans](#header-dental-quotes) section.  ### Provider Data The Dental Plans are paired with [Network Provider Data](#header-network-and-provider-data) 

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DentalPlansApi.new

body = VericredClient::DentalPlanSearchRequest.new # DentalPlanSearchRequest | 


begin
  #Search Plans
  result = api_instance.find_dental_plans(body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling DentalPlansApi->find_dental_plans: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**DentalPlanSearchRequest**](DentalPlanSearchRequest.md)|  | 

### Return type

[**DentalPlanSearchResponse**](DentalPlanSearchResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **put_dental_plan**
> put_dental_plan(vericred_id, body)

Create/update a Dental Plan

Add or update a Dental Plan to the database.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DentalPlansApi.new

vericred_id = "a234567b90" # String | The unique Vericred id

body = VericredClient::DentalPlanUpdateRequest.new # DentalPlanUpdateRequest | Dental Plan Record


begin
  #Create/update a Dental Plan
  api_instance.put_dental_plan(vericred_id, body)
rescue VericredClient::ApiError => e
  puts "Exception when calling DentalPlansApi->put_dental_plan: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vericred_id** | **String**| The unique Vericred id | 
 **body** | [**DentalPlanUpdateRequest**](DentalPlanUpdateRequest.md)| Dental Plan Record | 

### Return type

nil (empty response body)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_dental_plan**
> DentalPlanShowResponse show_dental_plan(id, opts)

Show Plan

### Retrieving Benefits for a Dental Plan Show the details of an individual Plan.  This includes all [benefits](#header-dental) for the Plan.  For more details on displaying Plans and their related data, see the [Quoting](#header-individual-quotes) section.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DentalPlansApi.new

id = "99eA4hhn" # String | ID of the Plan

opts = { 
  year: 2018 # Integer | Plan year (defaults to current year)
}

begin
  #Show Plan
  result = api_instance.show_dental_plan(id, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling DentalPlansApi->show_dental_plan: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Plan | 
 **year** | **Integer**| Plan year (defaults to current year) | [optional] 

### Return type

[**DentalPlanShowResponse**](DentalPlanShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_dental_plan_0**
> DentalPlanShowResponse show_dental_plan_0(id)

Show Plan

Show the details of a DentalPlan.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DentalPlansApi.new

id = "88582NY0230001" # String | ID of the Plan


begin
  #Show Plan
  result = api_instance.show_dental_plan_0(id)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling DentalPlansApi->show_dental_plan_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Plan | 

### Return type

[**DentalPlanShowResponse**](DentalPlanShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



