# VericredClient::DrugsApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_drug_coverages**](DrugsApi.md#get_drug_coverages) | **GET** /drugs/{id}/coverages | Drug Coverage Search
[**list_drugs**](DrugsApi.md#list_drugs) | **GET** /drugs | Drug Search


# **get_drug_coverages**
> DrugCoverageResponse get_drug_coverages(id, year, line_of_coverage, state_code, opts)

Drug Coverage Search

Drug coverages are the specific tier level, quantity limit, prior authorization and step therapy for a given Drug/Plan combination. This endpoint returns all drug coverages for a given Drug.  #### Tiers   Possible values for tier:    | Tier                     | Description                                                                                                                                                                     |   | ------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |   | __generic__              | Unbranded drugs, with the same active ingredients as their brand-name equivalents, and generally available at a lower cost.                                                     |   | __preferred_brand__      | Brand-name drugs included on the health plan's formulary. Generally more expensive than generics, and less expensive than non-preferred drugs.                                  |   | __non_preferred_brand__  | Brand-name drugs not included on the health plan's formulary. These generally have a higher coinsurance.                                                                        |   | __specialty__            | Used to treat complex conditions like cancer. May require special handling or monitoring. May be generic or brand-name. Generally the most expensive drugs covered by a plan.   |   | __not_covered__          | Specifically excluded from the health plan.                                                                                                                                     |   | __not_listed__           | Neither included nor excluded from the health plan. Most plans provide some default level of coverage for unlisted drugs.                                                       |

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DrugsApi.new

id = "bb1f3523f0" # String | ID of the Drug

year = "2019" # String | Plan Year

line_of_coverage = "medical" # String | Line of coverage (medical or medicare_advantage)

state_code = "CA" # String | Two-character state code

opts = { 
  market: "individual" # String | Plan Market (individual or small_group)
}

begin
  #Drug Coverage Search
  result = api_instance.get_drug_coverages(id, year, line_of_coverage, state_code, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling DrugsApi->get_drug_coverages: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Drug | 
 **year** | **String**| Plan Year | 
 **line_of_coverage** | **String**| Line of coverage (medical or medicare_advantage) | 
 **state_code** | **String**| Two-character state code | 
 **market** | **String**| Plan Market (individual or small_group) | [optional] 

### Return type

[**DrugCoverageResponse**](DrugCoverageResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **list_drugs**
> DrugDetails list_drugs(search_term)

Drug Search

Search for drugs by proprietary name.  **New Verison:** In order to use this endpoint, please set your version header to `v7`. We still support previous versions of this endpoint. For more information on how to set version headers, see [Versioning](#header-versioning) of this document.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::DrugsApi.new

search_term = "Zyrtec" # String | Full or partial proprietary name of drug


begin
  #Drug Search
  result = api_instance.list_drugs(search_term)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling DrugsApi->list_drugs: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search_term** | **String**| Full or partial proprietary name of drug | 

### Return type

[**DrugDetails**](DrugDetails.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



