# VericredClient::MedicalPlansApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**find_major_medical_plans**](MedicalPlansApi.md#find_major_medical_plans) | **POST** /plans/medical/search | Search Plans
[**put_medical_plan**](MedicalPlansApi.md#put_medical_plan) | **PUT** /plans/medical/{vericred_id} | Create/update a Medical Plan
[**show_medical_plan**](MedicalPlansApi.md#show_medical_plan) | **GET** /plans/medical/{id} | Show Plan


# **find_major_medical_plans**
> ACAPlan2018SearchResponse find_major_medical_plans(body)

Search Plans

### Searching for Medical Plans   Determine the available Plans and their Premiums for a particular Family in a given Location.   For details on searching for Plans and their related data, see the [Quoting Medical Plans](#header-major-medical-quotes) section.   **Notice:** Please note that there are potential breaking changes in the 2020 plan schema. For backwards compatibility, the previous schema will be maintained for plans before the 2020 plan year until January 2, 2020. For more information, please see our [2020 ACA Medical Plan Data Update](https://vericred-marketing.s3.amazonaws.com/vericred-communications/2020+ACA+Medical+Updates.pdf).  ### Parameters | Field                                             | Type     | Notes                                                                                                                     | |---------------------------------------------------|----------|---------------------------------------------------------------------------------------------------------------------------| | zip_code<br />_(required)_                        | `string` |                                                                                                                           | | fips_code<br />_(required)_                       | `string` |                                                                                                                           | | market<br />_(required)_                          | `string` | The options are: `individual` or `small_group`.                                                                           | | enrollment_date<br />_(optional)_                 | `string` | The format is `2019-01-01`. If this is not provided, we default it to today's date.                                       | | applicants<br />_(optional)_                      | `list`   | Use this field to see premiums for `individual` quotes. See below for parameters.                                         | | drug_packages<br />_(optional)_                   | `list`   | Use this field to see drug coverage information by plan. Supply either the NDC Package Code or the Med ID of the `Drug`.  | | household_income<br />_(optional)_                | `int`    | The total household income of the applicant for `individual` quotes.                                                      | | household_size<br />_(optional)_                  | `int`    | The number of applicants and dependents applying for `individual` quotes.                                                 | | ids<br />_(optional)_                             | `list`   | Use this field to hard filter results to certain HIOS IDs.                                                                | | providers<br />_(optional)_                       | `list`   | Use this field to see if providers are in- or out-of-network for each plan by providing their NPIs.                       | | issuer_qualifications_met<br />_(optional)_       | `list`   | A list of HIOS Issuer IDs of which the end-user has answered qualification questions for.                                 |  ### Applicants _(optional)_ | Field                                             | Type      | Notes | |---------------------------------------------------|-----------|-------| | age<br />_(required)_                             | `int`     |       | | child<br />_(required)_                           | `boolean` |       | | smoker<br />_(required)_                          | `boolean` |       |  ### Additional Sorting  Plans can be sorted by the `premium`, `carrier_name`, `level`, and `plan_type` fields, by either ascending (as `asc`) or descending (as `dsc`) sort under the `sort` field.  ### Provider Data  The Major Medical Plans are paired with [Network Provider Data](#header-network-and-provider-data)  ### Drug coverages  Are included along with the rest of the plan data. See [the description below](#drugcoverages) for more details.  ### Issuer Qualifications  Some issuers require end users to answer questions before their plans can be made available to them, e.g. certain Association Health Plans.  Vericred supports this by asking you to confirm that the end user has answered the requisite questions by passing the HIOS Issuer ID of the issuer in the optional `issuer_qualifications_met` request key.  Plans for the requested issuer(s) that are available in the geographic area will have a `-94` suffix in their `id`.   For information on the issuers with qualifications that are supported, please reach out to support@vericred.com.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::MedicalPlansApi.new

body = VericredClient::MedicalPlanSearchRequest.new # MedicalPlanSearchRequest | 


begin
  #Search Plans
  result = api_instance.find_major_medical_plans(body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling MedicalPlansApi->find_major_medical_plans: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**MedicalPlanSearchRequest**](MedicalPlanSearchRequest.md)|  | 

### Return type

[**ACAPlan2018SearchResponse**](ACAPlan2018SearchResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **put_medical_plan**
> put_medical_plan(vericred_id, body)

Create/update a Medical Plan

Add or update a Medical Plan to the database.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::MedicalPlansApi.new

vericred_id = "a234567b90" # String | The unique Vericred id

body = VericredClient::MedicalPlanUpdateRequest.new # MedicalPlanUpdateRequest | Medical Plan Record


begin
  #Create/update a Medical Plan
  api_instance.put_medical_plan(vericred_id, body)
rescue VericredClient::ApiError => e
  puts "Exception when calling MedicalPlansApi->put_medical_plan: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vericred_id** | **String**| The unique Vericred id | 
 **body** | [**MedicalPlanUpdateRequest**](MedicalPlanUpdateRequest.md)| Medical Plan Record | 

### Return type

nil (empty response body)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_medical_plan**
> PlanShowResponse show_medical_plan(id, opts)

Show Plan

### Retrieving Benefits for a Medical Plan Show the details of an individual Plan.  This includes all [benefits](#header-major-medical) for the Plan.  For more details on displaying Plans and their related data, see the [Quoting](#header-individual-quotes) section.  **Notice:** Please note that there are potential breaking changes in the 2020 plan schema. For backwards compatibility, the previous schema will be maintained for plans before the 2020 plan year until January 2, 2020. For more information, please see our [2020 ACA Medical Plan Data Update](https://vericred-marketing.s3.amazonaws.com/vericred-communications/2020+ACA+Medical+Updates.pdf).

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::MedicalPlansApi.new

id = "88582NY0230001" # String | ID of the Plan

opts = { 
  year: 2020 # Integer | Plan year (defaults to current year)
}

begin
  #Show Plan
  result = api_instance.show_medical_plan(id, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling MedicalPlansApi->show_medical_plan: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Plan | 
 **year** | **Integer**| Plan year (defaults to current year) | [optional] 

### Return type

[**PlanShowResponse**](PlanShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



