# VericredClient::NetworksApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_disruption_analysis**](NetworksApi.md#create_disruption_analysis) | **POST** /networks/disruption_analysis | Disruption Analysis
[**create_network_comparisons**](NetworksApi.md#create_network_comparisons) | **POST** /networks/{id}/network_comparisons | Compare Multiple Networks
[**list_networks**](NetworksApi.md#list_networks) | **GET** /networks | Network Search
[**show_network**](NetworksApi.md#show_network) | **GET** /networks/{id} | Display a Network


# **create_disruption_analysis**
> NetworkDisruptionAnalysisResponse create_disruption_analysis(body, opts)

Disruption Analysis

Calculate the percentage of provider NPIs that are out-of-network for a set of networks. If you are interested in using this endpoint, please contact support@vericred.com for more details.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::NetworksApi.new

body = VericredClient::NetworkDisruptionAnalysisRequest.new # NetworkDisruptionAnalysisRequest | 

opts = { 
  page: 1, # Integer | Page of paginated response
  per_page: 1 # Integer | Responses per page
}

begin
  #Disruption Analysis
  result = api_instance.create_disruption_analysis(body, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling NetworksApi->create_disruption_analysis: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**NetworkDisruptionAnalysisRequest**](NetworkDisruptionAnalysisRequest.md)|  | 
 **page** | **Integer**| Page of paginated response | [optional] 
 **per_page** | **Integer**| Responses per page | [optional] 

### Return type

[**NetworkDisruptionAnalysisResponse**](NetworkDisruptionAnalysisResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_network_comparisons**
> NetworkComparisonResponse create_network_comparisons(id, body)

Compare Multiple Networks

Compare provider counts in a given area between a base network and one or more comparison networks.  #### Comparing Networks Comparison of provider counts within a radius requires that you provide a `zip_code` and `radius` to use as a search area.  The response returns the total number of unique `Providers` in the Base `Network` (i.e. those who are not present in the Comparison `Network`), The number of unique `Provider`s in the Comparison `Network` (i.e. those who are not present in the Base `Network`), and the count of `Provider`s who are in *both* `Network`s

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::NetworksApi.new

id = 100001 # Integer | Primary key of the base network

body = VericredClient::NetworkComparisonRequest.new # NetworkComparisonRequest | 


begin
  #Compare Multiple Networks
  result = api_instance.create_network_comparisons(id, body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling NetworksApi->create_network_comparisons: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| Primary key of the base network | 
 **body** | [**NetworkComparisonRequest**](NetworkComparisonRequest.md)|  | 

### Return type

[**NetworkComparisonResponse**](NetworkComparisonResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **list_networks**
> NetworkSearchResponse list_networks(opts)

Network Search

The network search endpoint enables you to find networks by many parameters.  A network encompasses a list of the doctors, other health care providers, and hospitals that a plan has contracted with to provide medical care to its Members. This endpoint is paginated.  **New Verison:** In order to use this endpoint, please set your version header to `v7`. If you do not set the version header, you will be limited to the following parameters: `carrier_id`, `market`, `state`, and `effective_date` and you will see limited information in the response. For more information on how to set version headers, see [Versioning](#header-versioning) of this document.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::NetworksApi.new

opts = { 
  search_term: "Enhanced PPO", # String | Full or partial name of the network
  line_of_coverage: "medical", # String | The line of coverage of the network. Possible values are `medical`, `medicare_advantage`, `dental`
  carrier_id: "33333", # String | Carrier HIOS Issuer ID (e.g. 10544) or Medicare Contract Issuer ID (e.g. H2649)
  market: "individual", # String | Type of Plan to which this network is attached. Possible values are `individual`, `small_group`, `large_group`
  state_code: "CA", # String | A state code (e.g. CA) in which the network is available
  effective_date: "2019-01-01T00:00:00.000+0000", # String | Use this to specify a date on which the network must be or have been active
  page: 1, # Integer | Page of paginated response
  per_page: 10 # Integer | Responses per page
}

begin
  #Network Search
  result = api_instance.list_networks(opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling NetworksApi->list_networks: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search_term** | **String**| Full or partial name of the network | [optional] 
 **line_of_coverage** | **String**| The line of coverage of the network. Possible values are &#x60;medical&#x60;, &#x60;medicare_advantage&#x60;, &#x60;dental&#x60; | [optional] 
 **carrier_id** | **String**| Carrier HIOS Issuer ID (e.g. 10544) or Medicare Contract Issuer ID (e.g. H2649) | [optional] 
 **market** | **String**| Type of Plan to which this network is attached. Possible values are &#x60;individual&#x60;, &#x60;small_group&#x60;, &#x60;large_group&#x60; | [optional] 
 **state_code** | **String**| A state code (e.g. CA) in which the network is available | [optional] 
 **effective_date** | **String**| Use this to specify a date on which the network must be or have been active | [optional] 
 **page** | **Integer**| Page of paginated response | [optional] 
 **per_page** | **Integer**| Responses per page | [optional] 

### Return type

[**NetworkSearchResponse**](NetworkSearchResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_network**
> NetworkDetailsResponse show_network(id)

Display a Network

The network details endpoint enables you to get information about a network by providing its `id`.   A network encompasses a list of the doctors, other health care providers, and hospitals that a plan has contracted with to provide medical care to its Members.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::NetworksApi.new

id = 100001 # Integer | Primary key of the network


begin
  #Display a Network
  result = api_instance.show_network(id)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling NetworksApi->show_network: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| Primary key of the network | 

### Return type

[**NetworkDetailsResponse**](NetworkDetailsResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



