# VericredClient::ProvidersApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_provider**](ProvidersApi.md#delete_provider) | **DELETE** /providers/{npi} | Delete an NPI from a provider.
[**get_provider_plans**](ProvidersApi.md#get_provider_plans) | **GET** /providers/{npi}/plans | Provider Plans
[**get_providers**](ProvidersApi.md#get_providers) | **POST** /providers/search | Find Providers
[**put_provider**](ProvidersApi.md#put_provider) | **PUT** /providers/{npi} | Find a Provider


# **delete_provider**
> delete_provider(npi)

Delete an NPI from a provider.

Delete a provider to the database.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::ProvidersApi.new

npi = "1234567890" # String | NPI number


begin
  #Delete an NPI from a provider.
  api_instance.delete_provider(npi)
rescue VericredClient::ApiError => e
  puts "Exception when calling ProvidersApi->delete_provider: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **npi** | **String**| NPI number | 

### Return type

nil (empty response body)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **get_provider_plans**
> ProviderPlans get_provider_plans(npi, line_of_coverage, year, opts)

Provider Plans

Retrieve the plans a provider accepts.  **New Verison:** In order to use this endpoint, please set your version header to `v7`. If you are using previous versions and want to get the list of `plan_ids` that a provider accepts, you can use the `hios_ids` key in the Provider Show `GET /providers/:npi` endpoint.  #### External Id Types   Plan `external_ids` are returned as a list, with each item containing   both a `type` and a `value`. Below is a list of possible types:    | Type           | Description                                                                                                                                          |   | -------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------- |   | hios_id        | The HIOS ID of the plan. This type will be returned for under-65 ACA medical plans.                                                                  |   | contract_id    | A contract identifier for the plan. This will be returned for all Medicare Advantage plans and any other plan that contains external contract ids.   |   | package_code   | A package code for the plan. This value will be returned if there is a package in which the plan is bundled.                                         |

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::ProvidersApi.new

npi = "1234567890" # String | NPI number

line_of_coverage = "medical" # String | The line of coverage the plans are in. Options are `medical`, `medicare_advantage`, `dental`, or `vision`.

year = "2019" # String | The year the plans are effective in.

opts = { 
  market: "small_group" # String | The market the plans are for. Options are `individual`, `small_group`, `large_group`.
}

begin
  #Provider Plans
  result = api_instance.get_provider_plans(npi, line_of_coverage, year, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling ProvidersApi->get_provider_plans: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **npi** | **String**| NPI number | 
 **line_of_coverage** | **String**| The line of coverage the plans are in. Options are &#x60;medical&#x60;, &#x60;medicare_advantage&#x60;, &#x60;dental&#x60;, or &#x60;vision&#x60;. | 
 **year** | **String**| The year the plans are effective in. | 
 **market** | **String**| The market the plans are for. Options are &#x60;individual&#x60;, &#x60;small_group&#x60;, &#x60;large_group&#x60;. | [optional] 

### Return type

[**ProviderPlans**](ProviderPlans.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **get_providers**
> ProvidersSearchResponse get_providers(body)

Find Providers

### Provider Details All searches can take a `search_term`, which is used as a component in the score (and thus the ranking/order) of the results.  This is combined with the proximity to the location in ranking results. For example, we would want \"Dr. John Smith\" who is 5 miles away from a given Zip Code to appear before \"Dr. John Smith\" who is 100 miles away.  The weighting also allows for non-exact matches.  In our prior example, we would want \"Dr. Jon Smith\" who is 2 miles away to appear before the exact match \"Dr. John Smith\" who is 100 miles away because it is more likely that the user just entered an incorrect name.  The free text search also supports Specialty name search and \"body part\" Specialty name search.  So, searching \"John Smith nose\" would return \"Dr. John Smith\", the ENT Specialist before \"Dr. John Smith\" the Internist.  In addition, we can filter `Providers` by whether or not they accept *any* insurance.  Our data set includes over 4 million `Providers`, some of whom do not accept any insurance at all.  This filter makes it more likely that the user will find his or her practitioner in some cases.  ### Location Information  All `Provider` searches that do *not* specify `plan_ids` or `network_ids`require some type of location information. We use this information either to weight results or to filter results, depending on the type.  #### Network IDs This endpoint supports filtering provider search results to only those that are in-network for specific provider networks. To do so, you can provide a `network_ids` key in the request that includes a list of the identifiers for each network to filter on. Please note that the `network_ids` response key will only appear if it is used in the request. The use of this filter is reserved for paying customers.   #### Zip Code When providing the `zip_code` parameter, we order the `Providers` returned based on their score, which incorporates their proximity to the given Zip Code and the closeness of match to the search text.  If a `radius` is also provided, we filter out `Providers` who are outside of that radius from the center of the Zip Code provided.  #### Polygon When providing the `polygon` parameter, we filter providers who are outside the bounds of the shape provided.  This is mutually exclusive with `zip_code` and `radius`.  ### Specialty When providing the `specialty_ids` parameter, we filter providers to those who practice those specialties. To find the specialty_ids, please use the [Specialty Search](#specialtes-specialtes-get) endpoint.  ### Plan/Network Information We can also filter based on `Plan` and `Network` participation, using `plan_ids` and `network_ids`, respectively.  These filters are mutually exclusive and return the union of the resulting sets for each `Plan` or `Network`.  I.e. if you provider Plan A and Plan B, you will receive `Providers` who accept *either* `Plan`.  The same is true for `Networks`. The plan identifiers filter supports: Vericred plan IDs returned from the [Dental](#header-dental-quotes) and [Vision](#header-vision-quotes) endpoints, as well as, HIOS IDs and Medicare contract codes.  ### Examples  *Find Dr. Foo near Brooklyn*  `{ \"search_term\": \"Foo\", \"zip_code\": \"11215\" }`  *Find all Providers within 5 miles of Brooklyn who accept a Plan*  `{ \"zip_code\": \"11215\", \"radius\": 5, \"plan_ids\": [\"88582NY0230001\"] }`  *Find all providers on a map of Brooklyn ordered by a combination of proximity to the center point of the map and relevance to the search term \"ENT\"*  ``` {   \"polygon\": [       {\"lon\":-74.0126609802,\"lat\":40.6275684851 },       {\"lon\":-74.0126609802,\"lat\":40.7097269508 },       {\"lon\":-73.9367866516,\"lat\":40.7097269508 },       {\"lon\":-73.9367866516,\"lat\":40.6275684851 }   ],   \"search_term\" : \"ENT\" } ``` 

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::ProvidersApi.new

body = VericredClient::RequestProvidersSearch.new # RequestProvidersSearch | 


begin
  #Find Providers
  result = api_instance.get_providers(body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling ProvidersApi->get_providers: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**RequestProvidersSearch**](RequestProvidersSearch.md)|  | 

### Return type

[**ProvidersSearchResponse**](ProvidersSearchResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **put_provider**
> put_provider(npi, body)

Find a Provider

Add a new provider to the database.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::ProvidersApi.new

npi = "1234567890" # String | NPI number

body = VericredClient::Provider.new # Provider | Provider Record


begin
  #Find a Provider
  api_instance.put_provider(npi, body)
rescue VericredClient::ApiError => e
  puts "Exception when calling ProvidersApi->put_provider: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **npi** | **String**| NPI number | 
 **body** | [**Provider**](Provider.md)| Provider Record | 

### Return type

nil (empty response body)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



