# VericredClient::QuotingApi

All URIs are relative to *https://api.vericred.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_group**](QuotingApi.md#create_group) | **POST** /groups | Create a Group
[**create_group_quote**](QuotingApi.md#create_group_quote) | **POST** /groups/{id}/quotes | Create a Quote
[**show_group**](QuotingApi.md#show_group) | **GET** /groups/{id} | Display a Group
[**show_group_rates**](QuotingApi.md#show_group_rates) | **GET** /quotes/{id}/rates | Display Rates
[**show_rate_member_rates**](QuotingApi.md#show_rate_member_rates) | **GET** /rates/{id}/member_rates | Display Member Rates
[**update_group_members**](QuotingApi.md#update_group_members) | **PUT** /groups/{id}/members | Create or Update Members


# **create_group**
> GroupCreateResponse create_group(body)

Create a Group

Use this endpoint to create a new `Group`. See the [Overview Section](#header-specifying-the-group) for more information.  ### Parameters #### Group _(required)_ The `group` key is a required object that contains information related to the group that will be quoted.   | Field                                 | Type      | Notes                                                                        |   |---------------------------------------|-----------|------------------------------------------------------------------------------|   | chamber_association<br />_(required)_ | `boolean` |                                                                              |   | company_name<br />_(required)_        | `string`  |                                                                              |   | contact_email<br />_(optional)_       | `string`  |                                                                              |   | contact_name<br />_(optional)_        | `string`  |                                                                              |   | contact_phone<br />_(optional)_       | `string`  | The format is `123-123-1234`.                                                |   | external_id<br />_(required)_         | `string`  | A field you can use to identify the group with. This can be an empty string. |   | sic_code<br />_(required)_            | `string`  |                                                                              |  #### Locations _(required)_ The `locations` key is a requied list of objects, each detailing a location in which the group has an office. There should only be one primary location. The primary location is used to determine the plan availability for that group during the quoting process.   | Field                                 | Type      | Notes                                                                           |   |---------------------------------------|-----------|---------------------------------------------------------------------------------|   | external_id<br />_(optional)_         | `string`  | A field you can use to identify the location with. This can be an empty string. |   | fips_code<br />_(required)_           | `string`  |                                                                                 |   | name<br />_(required)_                | `string`  |                                                                                 |   | number_of_employees<br />_(required)_ | `integer` |                                                                                 |   | primary<br />_(required)_             | `boolean` |                                                                                 |   | zip_code<br />_(required)_            | `string`  |                                                                                 |

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

body = VericredClient::GroupCreateRequest.new # GroupCreateRequest | 


begin
  #Create a Group
  result = api_instance.create_group(body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->create_group: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**GroupCreateRequest**](GroupCreateRequest.md)|  | 

### Return type

[**GroupCreateResponse**](GroupCreateResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_group_quote**
> QuoteCreateResponse create_group_quote(id, opts)

Create a Quote

Generate a `Quote` for a `Group`. See the [Overview Section](#quoting-quoting-post-1) for more information.  ### Parameters #### Quote _(required)_ The `quote` key is required and it contains the criteria below for the quote that is being generated. | Field                                      | Type      | Notes                                                                                                                                                                            | |--------------------------------------------|-----------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| | contribution_percentage<br />_(required)_  | `integer` |                                                                                                                                                                                  | | effective_date<br />_(required)_           | `string`  | The format is `YYYY-MM-DD`.                                                                                                                                                      | | npn<br />_(required)_                      | `string`  | The National Producer Number                                                                                                                                                     | | participation_percentage<br />_(required)_ | `integer` |                                                                                                                                                                                  | | product_line<br />_(required)_             | `string`  | The product line you wish to quote for. The options are `medical`, `dental`, or `vision`.                                                                                        | | rating_method<br />_(required)_            | `string`  | The options are `age_banded`, `4_tier_composite`, `3_tier_composite`, `2_tier_composite`, and `adult_child_tier_composite`. If we do not have a method for a plan, we will use a method we have for that plan. | | voluntary<br />_(required)_                | `boolean` |                                                                                                                                                                                  | | carrier_ids<br />_(optional)_              | `list`    | A list of issuer_ids in string format. Only provide this key if you want to limit the carriers quoted.                                                                           |

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

id = "b215b6bcdb" # String | ID of the Group

opts = { 
  body: VericredClient::QuoteCreateRequest.new # QuoteCreateRequest | 
}

begin
  #Create a Quote
  result = api_instance.create_group_quote(id, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->create_group_quote: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Group | 
 **body** | [**QuoteCreateRequest**](QuoteCreateRequest.md)|  | [optional] 

### Return type

[**QuoteCreateResponse**](QuoteCreateResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_group**
> GroupShowResponse show_group(id)

Display a Group

Retrieve the details for a `Group`

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

id = "b215b6bcdb" # String | ID of the Group


begin
  #Display a Group
  result = api_instance.show_group(id)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->show_group: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Group | 

### Return type

[**GroupShowResponse**](GroupShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_group_rates**
> RatesShowResponse show_group_rates(id, opts)

Display Rates

Retrieve the rates for a `Quote`.  The `source` key shows the source from which we received the rates. The possible values are detailed below. | Source Value | Notes                                                                                                | | ------------ | ---------------------------------------------------------------------------------------------------- | | `carrier`    | The rates were received from a carrier.                                                              | | `state`      | The rates originate from state filings.                                                              | | `cms`        | The rates originate from Centers for Medicare & Medicaid Services (CMS) filings.                     | | `null`       | Only `Quote`s generated before the release of this key (2019-09-10) will contain null source values. |  The `premiums` key contains the available rating methods we have for the each plan. The rating methods are detailed below. | Premiums Key               | Notes                                                                                                                                                                        | |----------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| | age_banded                 | The keys include `total_member`, `total_dependent`, and `total`. The values are the sums.                                                                     | | 4_tier_composite           | The keys include `employee_only`, `employee_plus_spouse`, `employee_plus_children`, `employee_plus_family`, and `total`. The values are the per-member rate for each bucket. | | 3_tier_composite           | The keys include `employee_only`, `employee_plus_one`, `employee_plus_family`, and `total`. The values are the per-member rate for each bucket.                              | | 2_tier_composite           | The keys include `employee_only`, `employee_plus_family`, and `total`. The values are the per-member rate for each bucket.                                                   | | adult_child_tier_composite | The keys include `adult`, `child`, and `total`. The values are the per-member rate for each bucket.                                                                          |  **Notice:** Please note that the `premiums` key is currently only available for `medical` Quotes. Please reach out to support@vericred.com for updates on its availability for `dental` and `vision` quotes.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

id = "5db8ce543d" # String | ID of the quote

opts = { 
  page: 1, # Integer | Page of paginated response
  per_page: 1 # Integer | Responses per page
}

begin
  #Display Rates
  result = api_instance.show_group_rates(id, opts)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->show_group_rates: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the quote | 
 **page** | **Integer**| Page of paginated response | [optional] 
 **per_page** | **Integer**| Responses per page | [optional] 

### Return type

[**RatesShowResponse**](RatesShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **show_rate_member_rates**
> MemberRatesShowResponse show_rate_member_rates(id)

Display Member Rates

Retrieve the member-level rates for a particular `Rate` returned for a `Quote`.  The `premiums` key contains the available rating methods we have for the `Rate`, along with the member-specific rates for each method. For composite methods, the category the member falls into is shown.

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

id = "bb1f3523f0" # String | ID of the Rate


begin
  #Display Member Rates
  result = api_instance.show_rate_member_rates(id)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->show_rate_member_rates: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Rate | 

### Return type

[**MemberRatesShowResponse**](MemberRatesShowResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_group_members**
> MembersCreateResponse update_group_members(id, body)

Create or Update Members

Add `Member`s and their `Dependent`s to a `Group`. If called on the same group twice, it will fully replace the members for that group. See the [Overview Section](#quoting-quoting-put) for more information. ### Parameters #### Members _(required)_ The `members` key is a required list containing the `Member`s for the `Group` and their `Dependent`s.  | Field                                 | Type      | Notes                                                                                                | |---------------------------------------|-----------|------------------------------------------------------------------------------------------------------| | cobra<br />_(required)_               | `boolean` |                                                                                                      | | date_of_birth<br />_(required)_       | `string`  | The format is `YYYY-MM-DD`. Members cannot be less than 0 years old at the time of quoting.          | | dependents<br />_(required)_          | `list`    | If the member does not have dependents, please pass an empty list.                                   | | external_id<br />_(required)_         | `string`  | A field you can use to identify the member with. This can be an empty string.                        | | fips_code<br />_(required)_           | `string`  |                                                                                                      | | gender<br />_(required)_              | `string`  | The options are: `M` or `F`.                                                                         | | last_used_tobacco<br />_(required)_   | `string`  | The format is `YYYY-MM-DD`. For those that have never smoked, please pass `null`.                    | | location_id<br />_(required)_         | `string`  | The location where the member works. The identifier comes from the response when creating a `Group`. | | retiree<br />_(required)_             | `boolean` |                                                                                                      | | zip_code<br />_(required)_            | `string`  |                                                                                                      | ##### Dependents The `dependents` key is a required list containing each `Dependent` the `Member` has. If the `Member` has no dependents, an empty list should be passed.  | Field                                 | Type      | Notes                                                                                                     | |---------------------------------------|-----------|-----------------------------------------------------------------------------------------------------------| | date_of_birth<br />_(required)_       | `string`  | The format is `YYYY-MM-DD`. Dependents cannot be less than 0 years old at the time of quoting.            | | gender<br />_(required)_              | `string`  | The options are `M` or `F`.                                                                               | | last_used_tobacco<br />_(required)_   | `string`  | The format is `YYYY-MM-DD`. For those that have never smoked, please pass `null`.                         | | relationship<br />_(required)_        | `string`  | Please see the [Overview Section](#header-dependent-relationships) for a list of allowed relationships.   | | same_household<br />_(required)_      | `boolean` | Does the dependent live in the same household as the member?                                              |

### Example
```ruby
# load the gem
require 'vericred_client'
# setup authorization
VericredClient.configure do |config|
  # Configure API key authorization: Vericred-Api-Key
  config.api_key['Vericred-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Vericred-Api-Key'] = 'Bearer'
end

api_instance = VericredClient::QuotingApi.new

id = "b215b6bcdb" # String | ID of the Group

body = VericredClient::MembersCreateRequest.new # MembersCreateRequest | 


begin
  #Create or Update Members
  result = api_instance.update_group_members(id, body)
  p result
rescue VericredClient::ApiError => e
  puts "Exception when calling QuotingApi->update_group_members: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the Group | 
 **body** | [**MembersCreateRequest**](MembersCreateRequest.md)|  | 

### Return type

[**MembersCreateResponse**](MembersCreateResponse.md)

### Authorization

[Vericred-Api-Key](../README.md#Vericred-Api-Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



